# DLD module
This is constructed for basic operations in the Digital Logic Design
If you want any new methods to be added to the module, please fill the following form.
https://forms.gle/KnVQkgyFRMcUgjEfA

